summaryrefslogtreecommitdiffstats
path: root/src/dialogs/qfontdialog.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/dialogs/qfontdialog.cpp')
-rw-r--r--src/dialogs/qfontdialog.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/dialogs/qfontdialog.cpp b/src/dialogs/qfontdialog.cpp
index 995d49621..317a2ec1e 100644
--- a/src/dialogs/qfontdialog.cpp
+++ b/src/dialogs/qfontdialog.cpp
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
** Public Licensing retquirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
@@ -517,7 +517,7 @@ void TQListBoxFontText::paint( TQPainter *painter )
/*!
\internal
Updates the contents of the "font family" list box. This
- function can be reimplemented if you have special retquirements.
+ function can be reimplemented if you have special requirements.
*/
void TQFontDialog::updateFamilies()
@@ -605,7 +605,7 @@ void TQFontDialog::updateFamilies()
/*!
\internal
Updates the contents of the "font style" list box. This
- function can be reimplemented if you have special retquirements.
+ function can be reimplemented if you have special requirements.
*/
void TQFontDialog::updateStyles()
@@ -665,7 +665,7 @@ void TQFontDialog::updateStyles()
/*!
\internal
Updates the contents of the "font size" list box. This
- function can be reimplemented if you have special retquirements.
+ function can be reimplemented if you have special requirements.
*/
void TQFontDialog::updateSizes()
@@ -18,7 +18,7 @@
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please